// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KNOTIFICATIONS_VERSION_H
#define KNOTIFICATIONS_VERSION_H

#define KNOTIFICATIONS_VERSION_STRING "5.85.0"
#define KNOTIFICATIONS_VERSION_MAJOR 5
#define KNOTIFICATIONS_VERSION_MINOR 85
#define KNOTIFICATIONS_VERSION_PATCH 0
#define KNOTIFICATIONS_VERSION ((5<<16)|(85<<8)|(0))

#endif
